External Resources
==================

Online Tutorials
----------------

 * http://docs.openvswitch.org/en/latest/tutorials/faucet/
 * http://costiser.ro/2017/03/07/sdn-lesson-2-introducing-faucet-as-an-openflow-controller/
 * https://inside-openflow.com/openflow-tracks/faucet-controller-application-technical-track/
 * https://blog.cyberreboot.org/building-a-software-defined-network-with-raspberry-pis-and-a-zodiac-fx-switch-97184032cdc1

Tutorial Videos
---------------

 * https://www.youtube.com/watch?v=fuqzzjmcwlI
